/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.dao.impl;

import dk.sds.ecpr2.dao.OIDDAO;
import dk.sds.ecpr2.dao.exceptions.DAOException;
import dk.sds.ecpr2.dao.impl.abstr.AbstractDAOImpl;
import dk.sds.ecpr2.dao.impl.abstr.AbstractECPRDAOImpl;
import dk.sds.ecpr2.domain.OIDVO;
import dk.sds.ecpr2.util.TimeHelper;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public class OIDDAOImpl extends AbstractDAOImpl<OIDVO> implements OIDDAO {

    public static final String TABLE_NAME = "ecpr2.OID";

    @Override
    public OIDVO getByOIDValue(String oid) throws DAOException {
        final MapSqlParameterSource parameters = new MapSqlParameterSource()
                .addValue("oid", oid);
        String sql = "SELECT * FROM " + getTableName() + " WHERE `OID`=:oid";
        List<OIDVO> result = namedParamJdbcTemplate.query(sql, parameters, new OIDRowMapper());
        if (result.isEmpty()) {
            return null;
        } else if (result.size() > 1) {
            throw new DAOException("Multiple rows were found in table " + getTableName()
                    + " looking in column OID for the value " + oid);
        } else {
            return result.get(0);
        }
    }

    @Override
    public List<OIDVO> getAllOIDs() throws DAOException {
        return namedParamJdbcTemplate.query("SELECT * FROM " + getTableName(), new MapSqlParameterSource(), new OIDRowMapper());
    }

    @Override
    public OIDVO getByOIDValueAndType(String oid, String type) throws DAOException {
        final MapSqlParameterSource parms = new MapSqlParameterSource()
                .addValue("oid", oid)
                .addValue("type", type);
        String sql = "SELECT * FROM " + getTableName() + " WHERE `OID`=:oid AND `Type`=:type";
        List<OIDVO> result = namedParamJdbcTemplate.query(sql, parms, new OIDRowMapper());
        if (result.isEmpty()) {
            return null;
        } else if (result.size() > 1) {
            throw new DAOException("Multiple rows were found in table " + getTableName()
                    + " looking in column OID for the value " + oid + " and column Type for the value " + type);
        } else {
            return result.get(0);
        }
    }

    @Override
    public String getTableName() {
        return TABLE_NAME;
    }

    @Override
    protected RowMapper<OIDVO> getDefaultRowMapper() {
        return new OIDRowMapper();
    }
}

