/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.rest;

import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.springframework.stereotype.Service;

import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Optional;

/**
 * Responsible for serving WSDL files
 */
@WebServlet(name="wsdl", urlPatterns = {"/wsdl/*"})
@Service
public class WSDLController extends AbstractServlet {

    private static final String RESOURCE_NAME_DGWS_SERVICE = "/wsdl/ecpr2_dgws_service_inline_2017_10_01.wsdl";
    private static final String RESOURCE_NAME_DGWS_SERVICE_NO_SECURITY_HEADER = "/wsdl/ecpr2_dgws_service_inline_no_security_headers_2017_10_01.wsdl";

    private static final Logger log = LogManager.getLogger(WSDLController.class);

    @Override
    public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException {
        String path = Optional.ofNullable(request.getPathInfo()).orElse("");

        switch (path) {
            case "/dgws_service.wsdl":
                getFile(response, RESOURCE_NAME_DGWS_SERVICE);
                break;
            case "/dgws_service_no_security_header.wsdl":
                getFile(response, RESOURCE_NAME_DGWS_SERVICE_NO_SECURITY_HEADER);
                break;
            default:
                response.setStatus(404);
        }
    }

    public void getFile(HttpServletResponse response, String fileName) throws IOException {
        log.debug("wsdl" + fileName + " request");

        InputStream in = getClass().getResourceAsStream(fileName);
        BufferedReader reader = new BufferedReader(new InputStreamReader(in));
        StringBuilder out = new StringBuilder();
        String line;
        while ((line = reader.readLine()) != null) {
            out.append(line);
        }

        response.addHeader("Cache-Control", "no-cache");
        response.setHeader("Content-Type", "text/xml");
        response.setStatus(200);
        response.getWriter().println(out.toString());
    }
}
