/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.datagenerator;

import dk.sds.ecpr2.OID;
import dk.sds.ecpr2.dao.exceptions.DAOException;
import dk.sds.ecpr2.dao.impl.IdentifierDAOImpl;
import dk.sds.ecpr2.dao.impl.abstr.AbstractDAOImpl;
import dk.sds.ecpr2.domain.IdentifierVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;

import java.util.*;

@Component
@Order(value=10)
public class IdentifierGenerator extends AbstractGenerator {

    private final HashSet<String> xeCPRNumbers = new HashSet<>();

    public String getRandomXECPR() {
        String xeCPR;
        do {
            int year = getSkewedRandomIntBetween(1899, 2017, 1970);
            int month = getRandomIntBetween(1, 12);
            int day = getRandomIntBetween(1, 28);
            String yearString = String.valueOf(year).substring(2,4);
            int decade = year < 2000 ? 0 : 6;
            char char1 = getRandomChar();
            char char2 = getRandomChar();
            int gender = getRandomIntBetween(0,9);
            xeCPR = String.format("%02d%02d%s%d%s%s%d", day, month, yearString, decade, char1, char2, gender);
        } while (xeCPRNumbers.contains(xeCPR));

        xeCPRNumbers.add(xeCPR);

        return xeCPR;
    }
}
